@@ -27,6 +27,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 extern char *safeban(struct channel *, char *, char *);
 extern char *getfirsthostless(struct channel *, char *);
 extern char *getkickreason(char *);
+extern char getmodepol(char *, char);
 extern int topiccount(struct channel *);
 extern int settopic(struct channel *);
 extern int setnewtopic(struct channel *, char *, char *);
@@ -98,6 +99,8 @@ extern int deltrusted(char *);
 extern int delservice(char *);
 extern int delchannel(struct channel *);
 extern int deladverts(struct channel *, char *, int);
+extern int delchankey(struct channel *);
+extern int delchanlimit(struct channel *);
 extern int getondiskmsgcount(struct channel *, char *);
 extern int getondiskjoincount(struct channel *, char *);
 extern int getrandommsg(struct channel *, char *, int, char *, int, int);
@@ -162,7 +165,6 @@ extern void initjoins(struct channel *);
 extern void initnickbks(struct channel *);
 extern void initwordbks(struct channel *);
 extern void initusers(struct channel *);
-extern void linenoise(void);
 extern void checkstoned(void);
 extern void setuserhost(char *, char *);
 extern void sethostquerystatus(char *, int);
@@ -179,9 +181,6 @@ extern void listcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoffcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoncommand(struct channel *, char *, int, char *, char *, char *);
 extern void changetobek(struct channel *, char *, int);
-extern void setnick(void);
-extern void setumode(void);
-extern void sendqauth(void);
 extern void syncvoices(struct channel *);
 extern void syncops(struct channel *);
 extern void syncpermbans(struct channel *);
