@@ -41,7 +41,7 @@ int processactions(struct timed *);
 void establishconnection()
 {
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "establishconnection()\n");
+        oer_debug(OER_DEBUG_NOISE, "establishconnection()\n");
 #endif
         /* loop until a fatal error */
         while(!mystate->bailout) {
@@ -106,7 +106,7 @@ void reconnect()
 {
 	char stringbuffer[WRITE_BUFFER_LENGTH + 1];
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "reconnect()\n");
+        oer_debug(OER_DEBUG_NOISE, "reconnect()\n");
 #endif
 	/* check if connected */
 	if(mystate->current_server == NULL) {
@@ -197,7 +197,7 @@ int serverconnection()
 	struct hostent *hptr;
 	struct sockaddr_in servaddr;
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "serverconnection()\n");
+        oer_debug(OER_DEBUG_NOISE, "serverconnection()\n");
 #endif
 	/* check if we are already connected */
 	if(mystate->current_server != NULL) {
@@ -323,7 +323,7 @@ int registerconnection()
 	char *ptr;
 	struct passwd *pwd;
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "registerconnection()\n");
+        oer_debug(OER_DEBUG_NOISE, "registerconnection()\n");
 #endif
 	/* check if connected */
         if(mystate->current_server == NULL) {
@@ -418,7 +418,7 @@ int handleserverdata()
         size_t br;
         char *ptr;
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "handleserverdata()\n");
+        oer_debug(OER_DEBUG_NOISE, "handleserverdata()\n");
 #endif
 	i = 0;
 	cont = 1;
@@ -453,7 +453,7 @@ int handleserverdata()
 	/* here we log all the server traffic, prefix with timestamp */
 	if((index(mystate->flags, (int)'l') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
 		/* it doesn't matter if logging fails */
-		oer_doquery("handleserverdata", OER_DEBUG_FLOOD, "INSERT INTO raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysqlsafestr(stringbuffer, safe_string, READ_BUFFER_LENGTH));
+		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysqlsafestr(stringbuffer, safe_string, READ_BUFFER_LENGTH));
 	}
 	if((ptr = (char *) strstr(stringbuffer, "PING :")) != NULL) {
 		snprintf(pong, STRINGLEN, "PONG :%s\n", ptr + 6);
@@ -483,7 +483,7 @@ int processtimeds()
         struct timed *t2;
         char stringbuffer[WRITE_BUFFER_LENGTH + 1];
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "processtimeds()\n");
+        oer_debug(OER_DEBUG_NOISE, "processtimeds()\n");
 #endif
         /* check if connected */
         if(mystate->current_server == NULL) {
@@ -555,7 +555,7 @@ int processactions(struct timed *t)
 #ifdef DEBUG
 	/* prevent initial flooding of the console */
         if((mystate->now - mystate->current_server->linkup) >= 10) {
-		oer_debug(OER_DEBUG_FLOOD, "processactions(\"%lu\")\n", t->at);
+		oer_debug(OER_DEBUG_NOISE, "processactions(\"%lu\")\n", t->at);
 		oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, (int) (mystate->now - mystate->last_action.ts), mystate->last_action.barrier);
 	}
 #endif
