@@ -210,6 +210,7 @@ enum OER_DEBUG_LEVELS {
 	OER_DEBUG_ERROR = 2,
 	OER_DEBUG_WARNING = 3,
 	OER_DEBUG_INFO = 4,
+	OER_DEBUG_NOISE = 8,
 	OER_DEBUG_FLOOD = 9
 };
 
@@ -334,13 +335,14 @@ enum OER_TIMED_PRIORITIES {
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
 #define OER_MAX_LIST_LINES 5
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
+#define OER_SERVER_IS_STONED "server stoned"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define DEFAULT_WORDBK_MESSAGE "word ban-kick triggered, have a nice life..."
 #define DBSTATUS_MSG "At least one of the executed database queries failed, more \
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-28, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-29, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -537,6 +539,7 @@ struct channel {
 	int synced;
         int bantype;
 	int allhostsknown;
+        int whoquery;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t join_ts;
