@@ -53,6 +53,7 @@ void parseirc(char *serveroutput)
 	char outstring3[WRITE_BUFFER_LENGTH + 1];
 	char channel[CHANLEN + 1];
 	char mode[CHANLEN + 1];
+        char modeline[CHANLEN + 1];
 	char user[USERHOSTLEN + 1];
 	char host[USERHOSTLEN + 1];
 	char userhost[USERHOSTLEN + 1];
@@ -66,7 +67,7 @@ void parseirc(char *serveroutput)
 	struct channel *this;
 	struct chanuser *cu;
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "parseirc(\"%s\")\n", serveroutput);
+        oer_debug(OER_DEBUG_NOISE, "parseirc(\"%s\")\n", serveroutput);
 #endif
 	if(serveroutput[0] != ':') {
 		/* must be a command */
@@ -176,6 +177,18 @@ void parseirc(char *serveroutput)
 		/* this is the response to our ison query */
 		return;
 	}
+	if(!strcasecmp(command, "315")) {
+                /* end of WHO */
+                restpos = 0;
+                if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
+                        return;
+                }
+                if((this = getchptr(channel)) == NULL) {
+                        return;
+                }
+                this->whoquery = 1;
+                return;
+        }
 	if(!strcasecmp(command, "331")) {
 		/* no topic for channel */
 		return;
@@ -217,6 +230,43 @@ void parseirc(char *serveroutput)
 		/* returned when inviting someone */
 		return;
 	}
+	if(!strcasecmp(command, "352")) {
+                /* returned by the WHO query initiated in 366 */
+                restpos = 0;
+                if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
+                        return;
+                }
+                if((restpos = parse(restptr, restpos, " ", user, USERHOSTLEN, 0)) < 0) {
+                        return;
+                }
+                if((restpos = parse(restptr, restpos, " ", host, USERHOSTLEN, 0)) < 0) {
+                        return;
+                }
+                if((restpos = parse(restptr, restpos, " ", outstring, STRINGLEN, 0)) < 0) {
+                        return;
+                }
+                if((restpos = parse(restptr, restpos, " ", nick, NICKLEN, 0)) < 0) {
+                        return;
+                }
+                if((restpos = parse(restptr, restpos, " ", mode, CHANLEN, 0)) < 0) {
+                        return;
+                }
+                if((this = getchptr(channel)) == NULL) {
+                        return;
+                }
+                snprintf(userhost, USERHOSTLEN, "%s@%s", user, host);
+                setuserhost(nick, userhost);
+                if(index(mode, (int)'@')) {
+                        changeuser(this, nick, -1, 1, -1, -1);
+                }
+                if(index(mode, (int)'*')) {
+                        changeuser(this, nick, 1, -1, -1, -1);
+                }
+                if(index(mode, (int)'+')) {
+                        changeuser(this, nick, -1, -1, 1, -1);
+                }
+                return;
+        }
 	if(!strcasecmp(command, "353")) {
 		restpos = 0;
 		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN, 0)) < 0) {
@@ -277,6 +327,10 @@ void parseirc(char *serveroutput)
 		this->joined = 1;
 		this->joining = 0;
 		this->join_ts = mystate->now;
+		/* make a WHO query to get all userhosts & flags for
+		   nicks on channel */
+		snprintf(timed_str, WRITE_BUFFER_LENGTH, "WHO %s", this->name);
+		timed_new(NULL, mystate->now, OER_TIMED_TYPE_NORMAL, OER_TIMED_PRIORITY_CHANNEL_PROTECTION, timed_str);
 		return;
 	}
 	if(!strcasecmp(command, "372")) {
@@ -799,8 +853,19 @@ void parseirc(char *serveroutput)
                                         return;
                                 }
                                 restpos = nrestpos;
+				getnthmode(mode, i + 1, modeline);
+                                if(!strcasecmp(modeline, "+k")) {
+                                        strncpy(this->key, target, CHANLEN);
+                                        snprintf(outstring, STRINGLEN, "%s channel key is now %s", this->name, this->key);
+                                        sendreply(this->name, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
+                                }
+                                if(!strcasecmp(modeline, "-k")) {
+                                        memset(this->key, 0, CHANLEN);
+                                        snprintf(outstring, STRINGLEN, "deleted channel key from %s", this->name);
+                                        sendreply(this->name, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
+                                }
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->target is %s\n", target);
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->target is %s\n", target);
 #endif
                                 break;
                         case OER_NTHMODE_UNKNOWN:
@@ -809,12 +874,14 @@ void parseirc(char *serveroutput)
 			switch(modetype) {
                         case OER_NTHMODE_OP:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_OP\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_OP\n");
 #endif
                                 changeuser(this, target, -1, 1, -1, -1);
                                 if(isme(target)) {
                                         this->i_am_op = 1;
-                                        channelsync(this);
+					if(this->allhostsknown) {
+						channelsync(this);
+					}
                                         continue;
                                 }
                                 if(!this->i_am_op) {
@@ -833,7 +900,7 @@ void parseirc(char *serveroutput)
                                 break;
 			case OER_NTHMODE_DOP:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_DOP\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_DOP\n");
 #endif
                                 changeuser(this, target, -1, 0, -1, -1);
                                 if(isme(target)) {
@@ -851,19 +918,19 @@ void parseirc(char *serveroutput)
                                 break;
                         case OER_NTHMODE_VOICE:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_VOICE\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_VOICE\n");
 #endif
                                 changeuser(this, target, -1, -1, 1, -1);
                                 break;
 			case OER_NTHMODE_DVOICE:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_DVOICE\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_DVOICE\n");
 #endif
                                 changeuser(this, target, -1, -1, 0, -1);
                                 break;
 			case OER_NTHMODE_BAN:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_BAN\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_BAN\n");
 #endif
                                 snprintf(outstring, STRINGLEN, "%s!%s@%s", mystate->nick, mystate->user, mystate->host);
                                 if(wild_match(target, outstring)) {
@@ -887,7 +954,7 @@ void parseirc(char *serveroutput)
                                 break;
 			case OER_NTHMODE_UNBAN:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_UNBAN\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_UNBAN\n");
 #endif
                                 if(this->i_am_op && haschanflags(this, "e") && ispermban(this, target)) {
                                         if(isq(temp_nick) || isservice(temp_nick)) {
@@ -905,7 +972,7 @@ tried to remove the permban %s\n", temp_nick, channel, target);
                                 break;
 			case OER_NTHMODE_CHANMODE_WITHOUT_PARAMS:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITHOUT_PARAMS\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITHOUT_PARAMS\n");
 #endif
 				if(!isme(temp_nick)) {
 					this->setchanmode = 1;
@@ -913,7 +980,7 @@ tried to remove the permban %s\n", temp_nick, channel, target);
                                 break;
                         case OER_NTHMODE_CHANMODE_WITH_PARAMS:
 #ifdef DEBUG
-                                oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITH_PARAMS\n");
+                                oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITH_PARAMS\n");
 #endif
 				if(!isme(temp_nick)) {
 					this->setchanmode = 1;
@@ -2149,10 +2216,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
                 proceed = (isopa(userhost)) ? 1 : 0;
-                if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
-                        proceed = 1;
-                }
-                if(isatleastopnow(this, nick, userhost)) {
+                if(haschanflags(this, "U")) {
+			if(isatleastop(this, nick, userhost)) {
+				proceed = 1;
+			}
+		} else if(isatleastopnow(this, nick, userhost)) {
                         proceed = 1;
                 }
                 /* check if message was sent to a channel and if it was
@@ -2173,10 +2241,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
                 proceed = (isopa(userhost)) ? 1 : 0;
-                if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
-                        proceed = 1;
-                }
-                if(isatleastopnow(this, nick, userhost)) {
+                if(haschanflags(this, "U")) {
+			if(isatleastop(this, nick, userhost)) {
+				proceed = 1;
+			}
+		} else if(isatleastopnow(this, nick, userhost)) {
                         proceed = 1;
                 }
                 /* check if message was sent to a channel and if it was
@@ -2204,10 +2273,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
                 proceed = (isopa(userhost)) ? 1 : 0;
-                if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
-                        proceed = 1;
-                }
-                if(isatleastopnow(this, nick, userhost)) {
+                if(haschanflags(this, "U")) {
+			if(isatleastop(this, nick, userhost)) {
+				proceed = 1;
+			}
+		} else if(isatleastopnow(this, nick, userhost)) {
                         proceed = 1;
                 }
                 /* check if message was sent to a channel and if it was
@@ -2228,10 +2298,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
                 proceed = (isopa(userhost)) ? 1 : 0;
-                if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
-                        proceed = 1;
-                }
-                if(isatleastopnow(this, nick, userhost)) {
+                if(haschanflags(this, "U")) {
+			if(isatleastop(this, nick, userhost)) {
+				proceed = 1;
+			}
+		} else if(isatleastopnow(this, nick, userhost)) {
                         proceed = 1;
                 }
                 /* check if message was sent to a channel and if it was
