@@ -62,6 +62,7 @@ CREATE TABLE channels (
   name VARCHAR(50) NOT NULL DEFAULT '',
   chanmodes VARCHAR(12) DEFAULT '',
   chankey VARCHAR(32) DEFAULT '',
+  chanlimit VARCHAR(32) DEFAULT '',
   chanflags VARCHAR(32) DEFAULT '',
   ident VARCHAR(64) NOT NULL DEFAULT '',
   PRIMARY KEY (name,ident)
@@ -126,6 +127,19 @@ CREATE TABLE kickreasons (
   ident VARCHAR(64) NOT NULL DEFAULT ''
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'last'
+#
+
+CREATE TABLE last (
+  channel VARCHAR(50) NOT NULL,
+  nick VARCHAR(20) NOT NULL,
+  twhen INT UNSIGNED NOT NULL,
+  hostmask VARCHAR(80) NOT NULL,
+  message TEXT NOT NULL,
+  INDEX (channel,nick)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'nickbks'
 #
@@ -187,6 +201,18 @@ CREATE TABLE raw (
   message TEXT NOT NULL
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'seen'
+#
+
+CREATE TABLE seen (
+  channel VARCHAR(50) NOT NULL,
+  nick VARCHAR(20) NOT NULL,
+  twhen INT UNSIGNED NOT NULL,
+  hostmask VARCHAR(80) NOT NULL,
+  INDEX (channel,nick)
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'servers'
 #
